# Los geht's!

Willkommen zu Rapunzel, eine moderne Entwicklungsumgebung für Python und R. Hier sind ein paar nützliche Tastenkürzel.


## Arbeiten mit Projektordner und Dateien

- [`strg+Shift+O`: Öffne einen Projektordner](opensesame://event.rapunzel_welcome_open_folders)
- [`strg+O`: Öffne eine Datei aus einem Projektordner](opensesame://event.rapunzel_welcome_open_files)
- [`strg+N`: Erstelle ein leeres Dokument](opensesame://event.ide_new_file)


## Wenn's schnell gehen muss

- [`strg+Shift+P`: Aktiviere die Kommandopalette](opensesame://event.command_palette_activate)
- `strg+R`: Springe zur Funktion oder Klasse


## Ausführen von Code

- `F5`: Ausführen von Projekt oder Datei
- `F9`: Führe eine Auswahl, Zelle oder aktuelle Zeile aus. 
